==> verttice_ui-0.0.20.tar.gz: lib/src/widgets/form_factory/checkbox_form.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/widgets/border_label.dart';
import "package:flutter/material.dart";

class CheckboxFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final bool? value;
  final FormFieldState<dynamic>? state;

  const CheckboxFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
  }) : super(key: key);

  @override
  _CheckboxFormState createState() => _CheckboxFormState();
}

class _CheckboxFormState extends State<CheckboxFormFactory> {
  bool _value = false;

  @override
  void initState() {
    _value = DataClassUtils.dynamicToBool(widget.value, defultValue: false);
    super.initState();
  }

  @override
  void didUpdateWidget(covariant CheckboxFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToBool(widget.value, defultValue: false);
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName.length > 30
          ? widget.displayName.substring(0, 30) + "..."
          : widget.displayName,
      child: Row(
        children: [
          Expanded(
            child: SelectableText(
              widget.displayName,
              maxLines: 3,
              style:
                  const TextStyle(fontSize: 12.0, overflow: TextOverflow.clip),
            ),
          ),
          Checkbox(
            value: _value,
            onChanged: (bool? value) {
              widget.onChanged(widget.name, value);
              widget.state?.didChange(value);
            },
          ),
        ],
      ),
    );
  }
}

==> verttice_ui-0.0.74.tar.gz: lib/src/widgets/form_factory/checkbox_form.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_ui/src/widgets/border_label.dart';
import "package:flutter/material.dart";

class CheckboxFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final bool? value;
  final FormFieldState<dynamic>? state;

  const CheckboxFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
  }) : super(key: key);

  @override
  _CheckboxFormFactoryState createState() => _CheckboxFormFactoryState();
}

class _CheckboxFormFactoryState extends State<CheckboxFormFactory> {
  bool _value = false;

  @override
  void initState() {
    _value = DataClassUtils.dynamicToBool(widget.value, defultValue: false);
    super.initState();
  }

  @override
  void didUpdateWidget(covariant CheckboxFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToBool(widget.value, defultValue: false);
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName.length > 30
          ? widget.displayName.substring(0, 30) + "..."
          : widget.displayName,
      child: Row(
        children: [
          Expanded(
            child: SelectableText(
              widget.displayName,
              maxLines: 3,
              style:
                  const TextStyle(fontSize: 12.0, overflow: TextOverflow.clip),
            ),
          ),
          Checkbox(
            value: _value,
            onChanged: (bool? value) {
              widget.onChanged(widget.name, value);
              widget.state?.didChange(value);
            },
          ),
        ],
      ),
    );
  }
}
